==> fred_webwhois-3.1.3-py3-none-any.whl: webwhois/views/__init__.py <==
#
# Copyright (C) 2015-2023  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.
#
"""Webwhois views."""
from .detail_contact import ContactDetailView
from .detail_domain import DomainDetailView
from .detail_keyset import KeysetDetailView
from .detail_nsset import NssetDetailView
from .form_whois import WhoisFormView
from .public_request import (BlockObjectFormView, EmailInRegistryView, PersonalInfoFormView, PublicResponseNotFoundView,
                             PublicResponsePdfView, PublicResponseView, SendPasswordFormView, UnblockObjectFormView)
from .record_statement import ServeRecordStatementView
from .registrar import DownloadEvalFileView, RegistrarDetailView, RegistrarListView
from .resolve_handle_type import ResolveHandleTypeView
from .scan_results import ScanResultsView

__all__ = [
    'BlockObjectFormView',
    'ContactDetailView',
    'DomainDetailView',
    'DownloadEvalFileView',
    'EmailInRegistryView',
    'KeysetDetailView',
    'NssetDetailView',
    'PersonalInfoFormView',
    'PublicResponseNotFoundView',
    'PublicResponsePdfView',
    'PublicResponseView',
    'RegistrarDetailView',
    'RegistrarListView',
    'ResolveHandleTypeView',
    'ScanResultsView',
    'SendPasswordFormView',
    'ServeRecordStatementView',
    'UnblockObjectFormView',
    'WhoisFormView',
]

==> fred_webwhois-3.2.0-py3-none-any.whl: webwhois/views/__init__.py <==
#
# Copyright (C) 2015-2024  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.
#
"""Webwhois views."""
from .detail_contact import ContactDetailView
from .detail_domain import DomainDetailView
from .detail_keyset import KeysetDetailView
from .detail_nsset import NssetDetailView
from .form_whois import WhoisFormView
from .public_request import (
                             BlockObjectFormView,
                             EmailInRegistryView,
                             PersonalInfoFormView,
                             PublicResponseNotFoundView,
                             PublicResponsePdfView,
                             PublicResponseView,
                             SendPasswordFormView,
                             UnblockObjectFormView,
)
from .record_statement import ServeRecordStatementView
from .registrar import DownloadEvalFileView, RegistrarDetailView, RegistrarListView
from .resolve_handle_type import ResolveHandleTypeView
from .scan_results import ScanResultsView

__all__ = [
    'BlockObjectFormView',
    'ContactDetailView',
    'DomainDetailView',
    'DownloadEvalFileView',
    'EmailInRegistryView',
    'KeysetDetailView',
    'NssetDetailView',
    'PersonalInfoFormView',
    'PublicResponseNotFoundView',
    'PublicResponsePdfView',
    'PublicResponseView',
    'RegistrarDetailView',
    'RegistrarListView',
    'ResolveHandleTypeView',
    'ScanResultsView',
    'SendPasswordFormView',
    'ServeRecordStatementView',
    'UnblockObjectFormView',
    'WhoisFormView',
]
